package org.apache.struts2.interceptor;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionInvocation;
import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
import com.opensymphony.xwork2.interceptor.PreResultListener;
import java.util.Iterator;
import java.util.Set;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletResponse;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.struts2.interceptor.CookieProvider;

public class CookieProviderInterceptor extends AbstractInterceptor implements PreResultListener {

   private static final Logger LOG = LogManager.getLogger(CookieProviderInterceptor.class);


   public String intercept(ActionInvocation invocation) throws Exception {
      invocation.addPreResultListener(this);
      return invocation.invoke();
   }

   protected void addCookiesToResponse(CookieProvider action, HttpServletResponse response) {
      Set cookies = action.getCookies();
      Cookie cookie;
      if(cookies != null) {
         for(Iterator var4 = cookies.iterator(); var4.hasNext(); response.addCookie(cookie)) {
            cookie = (Cookie)var4.next();
            if(LOG.isDebugEnabled()) {
               LOG.debug("Sending cookie [{}] with value [{}] for domain [{}]", cookie.getName(), cookie.getValue(), cookie.getDomain() != null?cookie.getDomain():"no domain");
            }
         }
      }

   }

   public void beforeResult(ActionInvocation invocation, String resultCode) {
      try {
         LOG.trace("beforeResult start");
         ActionContext ex = invocation.getInvocationContext();
         if(invocation.getAction() instanceof CookieProvider) {
            HttpServletResponse response = (HttpServletResponse)ex.get("com.opensymphony.xwork2.dispatcher.HttpServletResponse");
            this.addCookiesToResponse((CookieProvider)invocation.getAction(), response);
         }

         LOG.trace("beforeResult end");
      } catch (Exception var5) {
         LOG.error("Unable to setup cookies", var5);
      }

   }

}
